@@ -18,7 +18,6 @@
 #include "MainQtWidget.h"
 #include "FractionRingWidget.h"
 
-class QHBoxLayout;
 class QPushButton;
 class MainQtWidget;
 class FractionRingWidget;
@@ -37,7 +36,7 @@ public:
     AppMenuWidget();
 
     /** destructor */
-    ~AppMenuWidget();
+    ~AppMenuWidget() override;
 
 private:
     QWidget * baseWidget;
